COPY_THRESHOLD: int
DRAFT_API: bool
__version__: str

from .backend import (
    IPC_PATH_MAX_LEN,
    PYZMQ_DRAFT_API,
    curve_keypair,
    curve_public,
    has,
    proxy,
    proxy_steerable,
    strerror,
    zmq_errno,
    zmq_poll,
)
from .constants import *
from .error import *
from .sugar import *

def get_includes() -> list[str]: ...
def get_library_dirs() -> list[str]: ...

__all__ = [
    'get_includes',
    'COPY_THRESHOLD',
    'DRAFT_API',
    'AFFINITY',
    'Again',
    'BACKLOG',
    'BINDTODEVICE',
    'BLOCKY',
    'BUSY_POLL',
    'CHANNEL',
    'CLIENT',
    'CONFLATE',
    'CONNECT_RID',
    'CONNECT_ROUTING_ID',
    'CONNECT_TIMEOUT',
    'CURVE',
    'CURVE_PUBLICKEY',
    'CURVE_SECRETKEY',
    'CURVE_SERVER',
    'CURVE_SERVERKEY',
    'Context',
    'ContextOption',
    'ContextTerminated',
    'DEALER',
    'DELAY_ATTACH_ON_CONNECT',
    'DGRAM',
    'DISCONNECT_MSG',
    'DISH',
    'DONTWAIT',
    'DeviceType',
    'DraftFDWarning',
    'EADDRINUSE',
    'EADDRNOTAVAIL',
    'EAFNOSUPPORT',
    'EAGAIN',
    'ECONNABORTED',
    'ECONNREFUSED',
    'ECONNRESET',
    'EFAULT',
    'EFSM',
    'EHOSTUNREACH',
    'EINPROGRESS',
    'EINVAL',
    'EMSGSIZE',
    'EMTHREAD',
    'ENETDOWN',
    'ENETRESET',
    'ENETUNREACH',
    'ENOBUFS',
    'ENOCOMPATPROTO',
    'ENOTCONN',
    'ENOTSOCK',
    'ENOTSUP',
    'EPROTONOSUPPORT',
    'ETERM',
    'ETIMEDOUT',
    'EVENTS',
    'EVENT_ACCEPTED',
    'EVENT_ACCEPT_FAILED',
    'EVENT_ALL',
    'EVENT_ALL_V1',
    'EVENT_ALL_V2',
    'EVENT_BIND_FAILED',
    'EVENT_CLOSED',
    'EVENT_CLOSE_FAILED',
    'EVENT_CONNECTED',
    'EVENT_CONNECT_DELAYED',
    'EVENT_CONNECT_RETRIED',
    'EVENT_DISCONNECTED',
    'EVENT_HANDSHAKE_FAILED_AUTH',
    'EVENT_HANDSHAKE_FAILED_NO_DETAIL',
    'EVENT_HANDSHAKE_FAILED_PROTOCOL',
    'EVENT_HANDSHAKE_SUCCEEDED',
    'EVENT_LISTENING',
    'EVENT_MONITOR_STOPPED',
    'EVENT_PIPES_STATS',
    'Enum',
    'Errno',
    'Event',
    'FAIL_UNROUTABLE',
    'FD',
    'FORWARDER',
    'Flag',
    'Frame',
    'GATHER',
    'GSSAPI',
    'GSSAPI_PLAINTEXT',
    'GSSAPI_PRINCIPAL',
    'GSSAPI_PRINCIPAL_NAMETYPE',
    'GSSAPI_SERVER',
    'GSSAPI_SERVICE_PRINCIPAL',
    'GSSAPI_SERVICE_PRINCIPAL_NAMETYPE',
    'HANDSHAKE_IVL',
    'HEARTBEAT_IVL',
    'HEARTBEAT_TIMEOUT',
    'HEARTBEAT_TTL',
    'HELLO_MSG',
    'HICCUP_MSG',
    'HWM',
    'IDENTITY',
    'IMMEDIATE',
    'INVERT_MATCHING',
    'IN_BATCH_SIZE',
    'IO_THREADS',
    'IPC_FILTER_GID',
    'IPC_FILTER_PID',
    'IPC_FILTER_UID',
    'IPC_PATH_MAX_LEN',
    'IPV4ONLY',
    'IPV6',
    'IntEnum',
    'IntFlag',
    'InterruptedSystemCall',
    'LAST_ENDPOINT',
    'LINGER',
    'LOOPBACK_FASTPATH',
    'MAXMSGSIZE',
    'MAX_MSGSZ',
    'MAX_SOCKETS',
    'MECHANISM',
    'METADATA',
    'MORE',
    'MSG_T_SIZE',
    'MULTICAST_HOPS',
    'MULTICAST_LOOP',
    'MULTICAST_MAXTPDU',
    'Message',
    'MessageOption',
    'MessageTracker',
    'NOBLOCK',
    'NORM_BLOCK_SIZE',
    'NORM_BUFFER_SIZE',
    'NORM_CC',
    'NORM_CCE',
    'NORM_CCE_ECNONLY',
    'NORM_CCL',
    'NORM_FIXED',
    'NORM_MODE',
    'NORM_NUM_AUTOPARITY',
    'NORM_NUM_PARITY',
    'NORM_PUSH',
    'NORM_SEGMENT_SIZE',
    'NORM_UNICAST_NACK',
    'NOTIFY_CONNECT',
    'NOTIFY_DISCONNECT',
    'NULL',
    'NormMode',
    'NotDone',
    'ONLY_FIRST_SUBSCRIBE',
    'OUT_BATCH_SIZE',
    'PAIR',
    'PEER',
    'PLAIN',
    'PLAIN_PASSWORD',
    'PLAIN_SERVER',
    'PLAIN_USERNAME',
    'POLLERR',
    'POLLIN',
    'POLLOUT',
    'POLLPRI',
    'PRIORITY',
    'PROBE_ROUTER',
    'PROTOCOL_ERROR_WS_UNSPECIFIED',
    'PROTOCOL_ERROR_ZAP_BAD_REQUEST_ID',
    'PROTOCOL_ERROR_ZAP_BAD_VERSION',
    'PROTOCOL_ERROR_ZAP_INVALID_METADATA',
    'PROTOCOL_ERROR_ZAP_INVALID_STATUS_CODE',
    'PROTOCOL_ERROR_ZAP_MALFORMED_REPLY',
    'PROTOCOL_ERROR_ZAP_UNSPECIFIED',
    'PROTOCOL_ERROR_ZMTP_CRYPTOGRAPHIC',
    'PROTOCOL_ERROR_ZMTP_INVALID_METADATA',
    'PROTOCOL_ERROR_ZMTP_INVALID_SEQUENCE',
    'PROTOCOL_ERROR_ZMTP_KEY_EXCHANGE',
    'PROTOCOL_ERROR_ZMTP_MALFORMED_COMMAND_ERROR',
    'PROTOCOL_ERROR_ZMTP_MALFORMED_COMMAND_HELLO',
    'PROTOCOL_ERROR_ZMTP_MALFORMED_COMMAND_INITIATE',
    'PROTOCOL_ERROR_ZMTP_MALFORMED_COMMAND_MESSAGE',
    'PROTOCOL_ERROR_ZMTP_MALFORMED_COMMAND_READY',
    'PROTOCOL_ERROR_ZMTP_MALFORMED_COMMAND_UNSPECIFIED',
    'PROTOCOL_ERROR_ZMTP_MALFORMED_COMMAND_WELCOME',
    'PROTOCOL_ERROR_ZMTP_MECHANISM_MISMATCH',
    'PROTOCOL_ERROR_ZMTP_UNEXPECTED_COMMAND',
    'PROTOCOL_ERROR_ZMTP_UNSPECIFIED',
    'PUB',
    'PULL',
    'PUSH',
    'PYZMQ_DRAFT_API',
    'PollEvent',
    'Poller',
    'QUEUE',
    'RADIO',
    'RATE',
    'RCVBUF',
    'RCVHWM',
    'RCVMORE',
    'RCVTIMEO',
    'RECONNECT_IVL',
    'RECONNECT_IVL_MAX',
    'RECONNECT_STOP',
    'RECONNECT_STOP_AFTER_DISCONNECT',
    'RECONNECT_STOP_CONN_REFUSED',
    'RECONNECT_STOP_HANDSHAKE_FAILED',
    'RECOVERY_IVL',
    'REP',
    'REQ',
    'REQ_CORRELATE',
    'REQ_RELAXED',
    'ROUTER',
    'ROUTER_BEHAVIOR',
    'ROUTER_HANDOVER',
    'ROUTER_MANDATORY',
    'ROUTER_NOTIFY',
    'ROUTER_RAW',
    'ROUTING_ID',
    'ReconnectStop',
    'RouterNotify',
    'SCATTER',
    'SERVER',
    'SHARED',
    'SNDBUF',
    'SNDHWM',
    'SNDMORE',
    'SNDTIMEO',
    'SOCKET_LIMIT',
    'SOCKS_PASSWORD',
    'SOCKS_PROXY',
    'SOCKS_USERNAME',
    'SRCFD',
    'STREAM',
    'STREAMER',
    'STREAM_NOTIFY',
    'SUB',
    'SUBSCRIBE',
    'SecurityMechanism',
    'Socket',
    'SocketOption',
    'SocketType',
    'Stopwatch',
    'SyncContext',
    'SyncSocket',
    'TCP_ACCEPT_FILTER',
    'TCP_KEEPALIVE',
    'TCP_KEEPALIVE_CNT',
    'TCP_KEEPALIVE_IDLE',
    'TCP_KEEPALIVE_INTVL',
    'TCP_MAXRT',
    'THREAD_AFFINITY_CPU_ADD',
    'THREAD_AFFINITY_CPU_REMOVE',
    'THREAD_NAME_PREFIX',
    'THREAD_PRIORITY',
    'THREAD_SAFE',
    'THREAD_SCHED_POLICY',
    'TOPICS_COUNT',
    'TOS',
    'TYPE',
    'UNSUBSCRIBE',
    'USE_FD',
    'VMCI_BUFFER_MAX_SIZE',
    'VMCI_BUFFER_MIN_SIZE',
    'VMCI_BUFFER_SIZE',
    'VMCI_CONNECT_TIMEOUT',
    'WSS_CERT_PEM',
    'WSS_HOSTNAME',
    'WSS_KEY_PEM',
    'WSS_TRUST_PEM',
    'WSS_TRUST_SYSTEM',
    'XPUB',
    'XPUB_MANUAL',
    'XPUB_MANUAL_LAST_VALUE',
    'XPUB_NODROP',
    'XPUB_VERBOSE',
    'XPUB_VERBOSER',
    'XPUB_WELCOME_MSG',
    'XREP',
    'XREQ',
    'XSUB',
    'XSUB_VERBOSE_UNSUBSCRIBE',
    'ZAP_DOMAIN',
    'ZAP_ENFORCE_DOMAIN',
    'ZMQBaseError',
    'ZMQBindError',
    'ZMQError',
    'ZMQVersionError',
    '_FINISHED_TRACKER',
    '__revision__',
    '__version__',
    'curve_keypair',
    'curve_public',
    'device',
    'has',
    'proxy',
    'proxy_steerable',
    'pyzmq_version',
    'pyzmq_version_info',
    'select',
    'strerror',
    'zmq_errno',
    'zmq_poll',
    'zmq_version',
    'zmq_version_info',
]
